==> qtjambi-xml-6.5.1-sources.jar: io/qt/xml/QDomDocumentFragment.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Tree of QDomNodes which is not usually a complete QDomDocument</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomdocumentfragment.html">QDomDocumentFragment</a></p>
 */
public class QDomDocumentFragment extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumentfragment.html#QDomDocumentFragment">QDomDocumentFragment::QDomDocumentFragment()</a></p>
     */
    public QDomDocumentFragment(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomDocumentFragment instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumentfragment.html#QDomDocumentFragment-1">QDomDocumentFragment::QDomDocumentFragment(QDomDocumentFragment)</a></p>
     */
    public QDomDocumentFragment(io.qt.xml.@NonNull QDomDocumentFragment x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomDocumentFragment instance, io.qt.xml.QDomDocumentFragment x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomdocumentfragment.html#operator-eq">QDomDocumentFragment::operator=(QDomDocumentFragment)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomDocumentFragment arg__1){
        assign_native_cref_QDomDocumentFragment(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomDocumentFragment(long __this__nativeId, long arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomDocumentFragment(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QDomDocumentFragment clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomDocumentFragment clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.5.2-sources.jar: io/qt/xml/QDomDocumentFragment.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Tree of QDomNodes which is not usually a complete QDomDocument</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qdomdocumentfragment.html">QDomDocumentFragment</a></code></p>
 */
public class QDomDocumentFragment extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomdocumentfragment.html#QDomDocumentFragment">QDomDocumentFragment::<wbr>QDomDocumentFragment()</a></code></p>
     */
    public QDomDocumentFragment(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomDocumentFragment instance);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomdocumentfragment.html#QDomDocumentFragment-1">QDomDocumentFragment::<wbr>QDomDocumentFragment(QDomDocumentFragment)</a></code></p>
     */
    public QDomDocumentFragment(io.qt.xml.@NonNull QDomDocumentFragment x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomDocumentFragment instance, io.qt.xml.QDomDocumentFragment x);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomdocumentfragment.html#operator-eq">QDomDocumentFragment::<wbr>operator=(QDomDocumentFragment)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomDocumentFragment arg__1){
        assign_native_cref_QDomDocumentFragment(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomDocumentFragment(long __this__nativeId, long arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QDomDocumentFragment(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QDomDocumentFragment clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomDocumentFragment clone_native(long __this_nativeId);
}
